clear all
set mem 10000m
set more off
capture log close

/*--------------------------
This file does some preliminary
anlysis of competitiveness of chiefdoms
using data from the oral history survey using the 2004 census.

Last Edit: TR, 10/25/11
---------------------------*/

log using $SL_log/chiefs_analysis_census04.log, replace

/*----------------------------------
1. Making Census Data File.
-----------------------------------*/

use $SL_data/census_2004_roster.dta
compress

rename chiefdom chiefcode_today
rename p11birth chiefcode_birth

gen never_moved = (chiefcode_birth==chiefcode_today)
replace never_moved = . if missing(chiefcode_birth)==1 | missing(chiefcode_today)==1

tab p8ethnic, gen(ethnicity)
drop ethnicity16 - ethnicity20

gen christian = inlist(p7religi,1,2,3,4,5,6)
replace christian = . if missing(p7religi)==1

rename p5age age
rename p6sex sex

gen age2 = age^2
gen age3 = age^3

gen married_one = inlist(p22marit,3,4)
gen disabled = p15==1

*gen age_10 = ( age<=10)
*gen age_11_20 = (age>10 & age<=20)
*gen age_21_30 = (age>20 & age<=30)
gen age_31_40 = (age>30 & age<=40)
gen age_41_50 = (age>40 & age<=50)
gen age_51_60 = (age>50 & age<=60)
gen age_61_70 = (age>60 & age<=70)
gen age_71_80 = (age>70 & age<=80)
gen age_81_90 = (age>80 & age<=90)

gen over30 = ( age>30 & missing(age)==0 )

gen birthyear = 2004-age
gen female = (sex==2)

gen literate = (p21liter==1)
lab var literate "Literate"

gen tertiary = inlist(p20highs,51,61,62,63,71,72,73)
replace tertiary = . if inlist(p20highs,1,2,92)
lab var tertiary "Achieved Tertiary Education"

gen secondary = inlist(p20highs,31,41)
replace secondary = . if inlist(p20highs,1,2,92)
replace secondary = 1 if tertiary == 1
lab var secondary "Achieved At Most Secondary Education"

gen primary = inlist(p20highs,11,21,22,23,24,25,26)
replace primary = . if inlist(p20highs,1,2,92)
replace primary = 1 if secondary==1
lab var primary "Achieved At Least Primary Education"

gen infant_mort = (p37alive == 2)
replace infant_mort = . if p37alive==.
lab var infant_mort "If had baby in last 12 months, is it dead?"
gen infant_full_immu = (p38immun == 1)
replace infant_full_immu = . if p38immun==.
lab var infant_full_immu "If had baby in last 12 months, does it have all immunizations?"
gen infant_partial_immu = (p38immun == 1 | p38immun == 3)
replace infant_partial_immu = . if p38immun==.
lab var infant_partial_immu "If had baby in last 12 months, does it have some immunizations?"

gen temp = 1 if age>=10
bys chiefcode_today: egen workers_today = total(temp)
drop temp
gen temp = (p25econo == 7 )
bys chiefcode_today: egen mining_today = total(temp)
drop temp

gen mining_share = mining_today/workers_today
 
gen private_sector_work = inlist(p25econo,8,10,11,12,13,14,15,20)
replace private_sector_work = . if age<10
lab var private "Works in manufacturing, construction, trade, hotel, tranp, finace, estates"

gen public_sector_work = inlist(p25econo,9,16,17,18,19,21)
replace public_sector_work = . if age<10
lab var public_sector_work "Works in utilities, military, social security, education, health, community service, NGO"

gen labor_force = inlist(p23activ,1,2,4,6)
replace labor_force = . if age<10
*This labor force definition corresponds to the one used in the 1963 census.

foreach i of numlist 1/21{
  loc job: label p25econ `i'
  gen job`i' = (p25econo == `i')
  lab var job`i' "`job'"
}

gen temne = ethnicity3
gen limba = ethnicity7
gen mende = ethnicity2

gen nonag = (private_sector_work == 1 | public_sector_work==1)
gen moved = 1 - never_moved

*Keeping important variables for replication analysis;
keep female age age2 ethnicity* temne limba mende primary secondary literate nonag private_sector_work chiefcode_today chiefcode_birth

/*Fixing outcomes for regressions*/

gen primary_orig = primary
gen literate_orig = literate
gen secondary_orig = secondary

replace primary = .b if age<=12
replace literate = .b if age<=12
replace secondary = .b if age<=18

/*Matching on Birth and Residence*/

foreach match in today birth{
  
preserve
use $SL_data/chiefs_survey_clean_out.dta, clear
rename chiefcode chiefcode_`match'
sort chiefcode_`match'
tempfile `match'
save ``match''
restore

preserve
sort chiefcode_`match'
merge m:1 chiefcode_`match'  using ``match''
keep if _m==3
drop _m
save $SL_data/chiefs_census_2004_`match'.dta, replace
restore

}

