
clear all
capture log close
set mem 500m

/*-----------------------------------------
This program produces the appendix table
with asset wealth indicators from the DHS
---------------------------------------------*/

/*1. Getting DHS Locations*/

insheet using $SL_data/chiefs_dhs_locations.txt

keep code dhsclust
rename code chiefcode

sort dhsclust

save $SL_data/chiefs_dhs_locations.dta, replace

/*2. Getting DHS Household Data*/
use $SL_data/dhs_hhold_SLHR51FL.DTA, clear

/*Recoding Missing*/
foreach var of varlist hv210 hv207 hv243a  {
    recode `var' (9 = .)
  }

/*Recoding Housing Quality*/
recode hv213 (11 12 13 21 22 = 0) (31 32 33 34 35 = 1) (96 99 = .)
recode hv214 ( 11 12 13 14 21 22 23 24 25 26 27 28 29 = 0) (31 32 33 34 35 36 = 1) (96 99 = .)
recode hv215  ( 11 12 13 14 21 22 23 24 25 26 27 28 29 = 0) (31 32 33 34 35 36 37 = 1) (96 99 = .)

rename hv213 nice_floor
rename hv214 nice_wall
rename hv215 nice_roof
rename hv270 dhs_wealth_index
rename hv243a phone
rename hv210 bike
rename hv207 radio

/*3. Merging Chiefs Data*/
rename hv001 dhsclust

sort dhsclust
merge m:1 dhsclust using $SL_data/chiefs_dhs_locations.dta
drop _m
tab chiefcode

lab val chiefcode chief_codes

merge m:1 chiefcode using $SL_data/chiefs_survey_clean_out.dta

list district chiefcode fam_num if _m==2
keep if _m==3
drop _m

save $SL_data/chiefs_dhs_hh.dta, replace
