clear all
set mem 1500m

/*----------------------------------------------------------------------
This file creates table 6 using 
the census data and the nps matched on chiefdom birth
-------------------------------------------------------------------------*/

loc exocontrol mitchell_km coast_dist rail_dist river_dist dist_min mining_1930

/*--------------------------
A. Moving to Opportunity
---------------------------*/

qui do $SL_do/chiefs_analysis_migration.do

rename fam_num_ln_birth fam_num_ln
rename amalgamation_birth amalgamation
rename n_chiefs_birth n_chiefs

lab var fam_num_ln "Ln(Families)"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

sum city if fam_num_ln!=. & age>12, d

/*1. Study Controls, District FE,  Demographic Controls*/

/*Without Historical Controls*/
regress city fam_num_ln amalgamation n_chiefs age age2 female ethnicity* i.district_birth if age>12, cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_appendix_residence", replace tex(frag) keep( fam_num_ln amalgamation n_chiefs) dec(3) nocons ctitle("City") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, NO)  sortvar( fam_num_ln amalgamation n_chiefs) noaster
  
/*With Historical Controls*/
regress city fam_num_ln amalgamation n_chiefs age age2 female ethnicity* `exocontrol' i.district_birth if age>12, cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_appendix_residence_exocontrols", replace tex(frag) keep( fam_num_ln amalgamation n_chiefs) dec(3) nocons  ctitle("City") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, YES)  sortvar( fam_num_ln amalgamation n_chiefs) noaster

/*-------------------
A. Non-Agricultural Employment (Today)
----------------------*/
  
loc kitchen_sink female age age2 ethnicity*
loc study_controls n_chiefs amalgamation

use $SL_data/chiefs_census_2004_today.dta, clear

rename chiefcode_today chiefcode

lab var fam_num_ln "Ln(Families)"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

foreach outcome of varlist nonag literate {

if "`outcome'" == "nonag"{
loc cond 10
}
else {
loc cond 12
}

/*Mean*/
sum `outcome' if missing(fam_num_ln)==0 & age>`cond'

/*1. Study Controls, District FE,  Demographic Controls*/

/*Without Historical Controls*/
  reg `outcome' fam_num_ln  amalgamation  n_chiefs dist1-dist12 `kitchen_sink'   if  age>`cond',  r  cluster(chiefcode)

outreg2 using "$SL_out/chiefs_appendix_residence", tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons ctitle("`outcome'") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, NO)  sortvar(fam_num_ln amalgamation n_chiefs) noaster
  
/*With Historical Controls*/
  reg `outcome' fam_num_ln  amalgamation  n_chiefs dist1-dist12 `kitchen_sink'  `exocontrol'  if  age>`cond' ,  r  cluster(chiefcode)

outreg2 using "$SL_out/chiefs_appendix_residence_exocontrols",   tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("`outcome'") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, YES)  sortvar(fam_num_ln amalgamation n_chiefs) noaster

/*2. Study Controls, District FE, Demographic Controls, Researcher FE*/
reg `outcome' fam_num_ln amalgamation n_chiefs  research_dummy*  dist1-dist12 `kitchen_sink'   if  age>`cond' ,  r  cluster(chiefcode)

outreg2 using "$SL_out/chiefs_appendix_residence_researcher_appendix", replace tex(frag) keep (fam_num_ln) dec(3) nocons  ctitle("`outcome'") addtext(District fixed effects, YES, Demographic controls, YES, Researcher FE, YES)  sortvar(fam_num_ln amalgamation n_chiefs) noaster

}

/*----------------
B: NPS (TODAY)
-------------------*/

loc controls female age age2 ethnicity*
loc study_controls amalgamation n_chiefs 
loc district_fe dist? dist??

/*B1. Matched on Today*/
use $SL_data/chiefs_nps_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

foreach y of varlist respect_authority bridging bonding collective {
d
  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
  
/*1. Regression with District FE and Controls*/

/*Without Historical Controls*/  
  reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_appendix_residence.tex",  tex(frag) keep(fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, NO)
  
/*With Historical Controls*/  
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' `exocontrol' [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_appendix_residence_exocontrols.tex",  tex(frag) keep(fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, YES)

/*2. Regression with Study Controls, District FE, Demographic controls, Researcher FE*/
reg `y' fam_num_ln `study_controls' `district_fe' `controls' research_dummy* [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_appendix_residence_researcher_appendix.tex",  tex(frag) keep(fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Researcher Fixed Effects, YES)
  
}

