clear all
set mem 10000m
set more off
capture log close

/*--------------------------
This file produces the two functional form graphs in Figure 3.

Last Edit: TR, 5/5/13
---------------------------*/

log using $SL_log/chiefs_census_func_form.log, replace

/*--------------------------------------------------------------
1. Scatter Plots for Showing Functional Form of Literacy
----------------------------------------------------------------*/

loc run = 1
if `run' == 1{

use $SL_data/chiefs_census_2004_birth.dta, clear

/*1. Creating Predicted values from our model*/
loc kitchen_sink female age age2 ethnicity*
loc study_controls n_chiefs amalgamation

loc group birth
loc cond 12
loc district_fe dist? dist??

reg literate fam_num_ln n_chiefs amalgamation `kitchen_sink' `district_fe' if  age>`cond', r cluster(chiefcode_birth)

loc b_model = round(_b[fam_num_ln],0.001)
loc se_model = round(_se[fam_num_ln],0.001)

/*2.a. Creating Predicted Value from model; using model mean as intercept.*/
predict lit_predict if e(sample)==1, xb
gen fam_effect = _b[fam_num_ln]*fam_num_ln
replace lit_predict = lit_predict - fam_effect
egen lit_mean = mean(lit_predict)

gen literacy_model= lit_mean + fam_effect

/*2.b. Cleaning up for Collapse*/
egen tag = tag(chiefcode_birth)
replace literacy_model = . if tag==0
codebook literacy_model

/*3.a. Predicting Exogenous Component of Literacy*/
reg literate mitchell_km rail_dist coast_dist river_dist dist_min mining_1930 `district_fe'  if age>`cond'
predict lit_exo if e(sample)==1, xb

/*4. Collapsing*/
collapse (mean) literate lit_exo (max) literacy_model, by( amalgamation n_chiefs chiefcode_birth fam_num_ln fam_num)
drop if fam_num==.

/*5. Creating Mean of Our Model for Fitted Line*/
bys fam_num: egen model_mean = mean(literacy_model)

/*6. Graph of Functional Form*/
twoway (scatter literate fam_num) (connected model_mean fam_num, connect(ascending) sort(fam_num) msymbol(i) ), yscale(range(0 0.5)) xscale(range(0 12)) scheme(sj) xtitle(Number of ruling families) ytitle(2004 literacy rate by chiefdom of birth) legend(off) note("Coefficient of literacy on log number of families is `b_model' (`se_model')")

graph save $SL_graph/literacy, replace

/*7a. Graph of Exogenous Component*/

/*Without district FE
regress lit_exo fam_num_ln amalgamation n_chiefs, r

loc b_xmodel = round(_b[fam_num_ln],0.001)
loc se_xmodel = round(_se[fam_num_ln],0.001)*/

gen district = floor(chiefcode_birth/100)
regress lit_exo fam_num_ln amalgamation n_chiefs i.district, r

loc b_xmodel = round(_b[fam_num_ln],0.001)
loc se_xmodel = round(_se[fam_num_ln],0.001)

/*7b. Creating Predicted Value from model; using model mean as intercept.*/
predict lit_predict if e(sample)==1, xb
gen fam_effect = _b[fam_num_ln]*fam_num_ln
replace lit_predict = lit_predict - fam_effect
egen lit_mean = mean(lit_predict)

gen model_exo = lit_mean + fam_effect

/*7c. Printing Graph*/
twoway (scatter lit_exo fam_num) (connected model_exo fam_num, connect(ascending) sort(fam_num) msymbol(i) ), xscale(range(0 12)) yscale(range(0 0.5) )  ylabel( 0.1 0.2 0.3 0.4 0.5 , norescale labels ticks grid) scheme(sj) xtitle(Number of ruling families) ytitle(Exogenous 2004 literacy rate by chiefdom of birth) legend(off) note("Coefficient of literacy on log number of families is 0.01 (0.006)" )

graph save $SL_graph/literacy_exo, replace


}














log close


