clear all
set mem 100m
set more off
capture log close

log using $SL_log/chiefs_table2_rr.log, replace

use $SL_data/chiefs_survey_clean_out.dta, clear

/*------------------------------------------------
This program produces Table 2 and figures showing the
relationship between the number of ruling families
and our two measures of concentration of power.
---------------------------------------------------*/

loc exocontrols mitchell_km coast_dist rail_dist river_dist dist_min mining_1930
  
/*Summary Statistics for Table 1*/
foreach y in n_chiefs amalgamation herf max_seats fam_num {
  mean `y' if missing(fam_cat)==0
  tabstat `y', by(fam_cat) stat(mean sd)
}

/*-------------------
Table 2
---------------------*/

lab var fam_num "Families"
lab var fam_num_ln "Ln(of families)"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

loc run = 1
if `run' == 1{

  
regress herf_a fam_num, r

outreg2 using "$SL_out/chiefs_table2.tex", replace tex(frag) drop(dist_* ) dec(2) e(F) title("First stage") addtext( District fixed effects, NO, Historical Controls, NO )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress herf_a fam_num_ln , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* ) dec(2) e(F) title("First stage") addtext( District fixed effects, NO, Historical Controls, NO )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress herf_a fam_num_ln n_chiefs amalgamation  `district_fe' , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* ) dec(2)  title("First stage") addtext( District fixed effects, YES, Historical Controls, NO )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress herf_a  fam_num_ln n_chiefs amalgamation  `district_fe' `exocontrols' , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* `exocontrols') dec(2)  title("First stage") addtext( District fixed effects, YES, Historical Controls, YES )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress herf_a fam_num fam_num_ln n_chiefs amalgamation  `district_fe' `exocontrols', r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_*  `exocontrols') dec(2)  title("First stage") addtext( District fixed effects, YES, Historical Controls, YES)  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress max_seats fam_num, r

outreg2 using "$SL_out/chiefs_table2.tex",  tex(frag) drop(dist_* ) dec(2) e(F) title("First stage") addtext( District fixed effects, NO, Historical Controls, NO )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress max_seats fam_num_ln , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* ) dec(2) e(F) title("First stage") addtext( District fixed effects, NO, Historical Controls, NO )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress max_seats fam_num_ln n_chiefs amalgamation  `district_fe' , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* ) dec(2)  title("First stage") addtext( District fixed effects, YES, Historical Controls, NO )  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress max_seats fam_num_ln n_chiefs amalgamation  `district_fe'  `exocontrols' , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* `exocontrols' ) dec(2)  title("First stage") addtext( District fixed effects, YES, Historical Controls, YES)  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

regress max_seats fam_num fam_num_ln n_chiefs amalgamation  `district_fe' `exocontrols' , r

outreg2 using "$SL_out/chiefs_table2.tex", tex(frag) drop(dist_* `exocontrols' ) dec(2)  title("First stage") addtext( District fixed effects, YES, Historical Controls, YES)  sortvar(fam_num fam_num_ln n_chiefs) nocons noaster label

/*Kill Run Loop*/
}


/*-------------------
Graph
---------------------*/

/*Herfhindahl*/
regress herf_a fam_num_ln amalgamation n_chiefs `district_fe' research_dummy* 
predict herf_predict if e(sample)==1, xb
gen fam_effect = _b[fam_num_ln]*fam_num_ln
replace herf_predict = herf_predict - fam_effect
egen herf_mean = mean(herf_predict)

gen model_herf = herf_mean + fam_effect
drop fam_effect
  
twoway (scatter herf_a fam_num)  (connected model_herf fam_num, connect(ascending) sort(fam_num) msymbol(i) ) , legend( off ) ytitle("Herfindahl index of office holding concentration") xtitle("Number of ruling families") ylabel( 0(.2)1) scheme(sj)
graph save  $SL_graph/table_2_herf, replace

/*Max Seats*/
regress max_seats fam_num_ln amalgamation n_chiefs `district_fe' research_dummy* 
predict max_seats_predict if e(sample)==1, xb
gen fam_effect = _b[fam_num_ln]*fam_num_ln
replace max_seats_predict = max_seats_predict - fam_effect
egen max_seats_mean = mean(max_seats_predict)

gen model_max_seats = max_seats_mean + fam_effect
drop fam_effect

twoway (scatter max_seats fam_num)  (connected model_max_seats fam_num, connect(ascending) sort(fam_num) msymbol(i) ) , legend( off ) ytitle("Number of seats held by the family with the most seats") xtitle("Number of ruling families") ylabel( 0(4)16)  scheme(sj)
graph save  $SL_graph/table_2_max_seats, replace


/*-----------------------------
Original Graphs from Before R&R

lab var herf "Herfindahl (=1 indicates dominance of one family)"
lab var max_seats "Number of Seats held by Family with Most Seasts"

twoway (scatter herf fam_num_ln) (lfit herf fam_num_ln) , legend( off ) ytitle("Herfindahl") xtitle("ln( Number of ruling families)") ylabel( 0(.2)1) scheme(sj)
graph export  $SL_graph/first_stage_log_herf.pdf, replace

twoway (scatter max_seats fam_num_ln) (lfit max_seats fam_num_ln) , legend( off ) ytitle("Number of seats held by the family with the most seats") xtitle("ln( Number of ruling families)") ylabel( 0(4)16) scheme(sj)
graph export  $SL_graph/first_stage_log_maxseats.pdf, replace

------------------------------*/

log close
