

/*-----------------------------------------------
Analyizing Early Determinants of Number of Families
-----------------------------------------------*/

use $SL_data/chiefs_survey_clean_out.dta, clear


/*Changing Units*/
replace taxpop63= taxpop63*1000
replace taxarea = taxarea*100

foreach y in taxarea taxpop63 mitchell_km coast_dist river_dist rail_dist dist_min mining_1930{
  sum `y' if missing(fam_cat)==0
  tabstat `y', by(fam_cat) stat(mean sd)
}

/*------------------
Key Regressions
--------------------*/

lab var fam_num "Number of families"
lab var fam_num_ln "Ln(Number of families)"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of seats observed"


replace pop63_stranger = pop63_stranger/1000

  *Summary Stats
sum taxarea
loc mean = round(r(mean),.01)
loc sd = round(r(sd),.01)

   *Levels
   reg taxarea fam_num amalgamation n_chiefs dist? dist?? , r
   outreg2 using "$SL_out/chiefs_table_exclusion.tex", tex(frag) drop(dist? dist??) dec(2) label replace noaster   nocons  addtext(Mean, `mean', SD, `sd')

   *Logs
   reg taxarea fam_num_ln amalgamation n_chiefs dist? dist??, r
   outreg2 using "$SL_out/chiefs_table_exclusion_ln.tex", tex(frag) drop(dist? dist??) dec(2) label  replace noaster   nocons  addtext(Mean, `mean', SD, `sd')

sum taxpop63
loc mean = round(r(mean),.01)
loc sd = round(r(sd),.01)

   *Levels  
   reg taxpop63 fam_num amalgamation n_chiefs dist? dist?? , r
   outreg2 using "$SL_out/chiefs_table_exclusion.tex", tex(frag) drop(dist? dist??) dec(2) label noaster   nocons  addtext(Mean, `mean', SD, `sd')
  
   reg taxpop63 fam_num amalgamation n_chiefs pop63_stranger dist? dist??, r
   outreg2 using "$SL_out/chiefs_table_exclusion.tex", tex(frag) drop(dist? dist??) dec(2) label  noaster   nocons  addtext(Mean, `mean', SD, `sd')
  
   *Logs
   reg taxpop63 fam_num_ln amalgamation n_chiefs dist? dist??, r
   outreg2 using "$SL_out/chiefs_table_exclusion_ln.tex", tex(frag) drop(dist? dist??) dec(2) label  noaster   nocons  addtext(Mean, `mean', SD, `sd')
  
   reg taxpop63 fam_num_ln amalgamation n_chiefs pop63_stranger dist? dist??, r
   outreg2 using "$SL_out/chiefs_table_exclusion_ln.tex", tex(frag) drop(dist? dist??) dec(2) label noaster   nocons  addtext(Mean, `mean', SD, `sd')

 
foreach var of varlist mining_1930 coast_dist river_dist mitchell_km rail_dist dist_min  {
  
sum `var'
loc mean = round(r(mean),.01)
loc sd = round(r(sd),.01)
  
   reg `var' fam_num amalgamation n_chiefs dist? dist??, r
   outreg2 using "$SL_out/chiefs_table_exclusion.tex", tex(frag) drop(dist? dist??) dec(2) label  noaster   nocons addtext(Mean, `mean', SD, `sd')

   reg `var' fam_num_ln amalgamation n_chiefs dist? dist??, r
   outreg2 using "$SL_out/chiefs_table_exclusion_ln.tex", tex(frag) drop(dist? dist??) dec(2) label noaster   nocons  addtext(Mean, `mean', SD, `sd')   

}

/*Final Two Columns are in chiefs_census_func_form.do*/
